==> hbase-client-1.3.1-sources.jar: org/apache/hadoop/hbase/UnknownScannerException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;


/**
 * Thrown if a region server is passed an unknown scanner id.
 * Usually means the client has take too long between checkins and so the
 * scanner lease on the serverside has expired OR the serverside is closing
 * down and has cancelled all leases.
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class UnknownScannerException extends DoNotRetryIOException {
  private static final long serialVersionUID = 993179627856392526L;

  /** constructor */
  public UnknownScannerException() {
    super();
  }

  /**
   * Constructor
   * @param s message
   */
  public UnknownScannerException(String s) {
    super(s);
  }

  public UnknownScannerException(String s, Exception e) {
    super(s, e);
  }
}

==> hbase-client-2.0.0-sources.jar: org/apache/hadoop/hbase/UnknownScannerException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.yetus.audience.InterfaceAudience;


/**
 * Thrown if a region server is passed an unknown scanner id.
 * Usually means the client has take too long between checkins and so the
 * scanner lease on the serverside has expired OR the serverside is closing
 * down and has cancelled all leases.
 */
@InterfaceAudience.Public
public class UnknownScannerException extends DoNotRetryIOException {
  private static final long serialVersionUID = 993179627856392526L;

  /** constructor */
  public UnknownScannerException() {
    super();
  }

  /**
   * Constructor
   * @param s message
   */
  public UnknownScannerException(String s) {
    super(s);
  }

  public UnknownScannerException(String s, Exception e) {
    super(s, e);
  }
}
